aaa = '工资单_workbook_xls__20250522140431350343'
aaa

bbb = r'https://d.docs.live.net/9122e41a29eea899/sb_yufengguang/xls/t6/%E5%B7%A5%E8%B5%84%E5%8D%95_workbook_xls__20250522140431350343.xlsx'
bbb

#import f_excel.over.open_and_process_excel as ov


#ov.open_and_process_excel(bbb)


import frankyu.xlsx.url_3 as ur
ur.url(bbb,aaa)