aaa = '世界简史 workbook_xls__20250623094705329139'
aaa

bbb = r'https://d.docs.live.net/9122e41a29eea899/sb_yufengguang/xls/%E4%B8%96%E7%95%8C%E7%AE%80%E5%8F%B2%20workbook_xls__20250623094705329139.xlsx'
bbb

#import f_excel.over.open_and_process_excel as ov


#ov.open_and_process_excel(bbb)


import frankyu.xlsx.url_3 as ur
ur.url(bbb,aaa)