aaa = r'''


历史告诉我们，道德主义（即混淆称义与成圣）从未彻底灭绝，只是定期休眠一下而已。宗教改革曾击溃了统治教会千年的道德主义。然而，好景不长，甚至在路德还没去世之前，改革之后的教会内部也浮现出道德主义的影子。它潜伏在亚米念的神学里，在巴克斯特的神学里（以及那些受他影响的正统改革宗），在十八世纪苏格兰的新律法主义里，在十九世纪的牛津运动里，在查尔斯·芬尼的思想里。在美国历史的大部分时期，道德主义几乎可以说在主导着美国的基督教（不论是福音派或是自由派）。

最近几年来，北美长老会与改革宗联会（NAPARC）和微型宗派的圈子里，正统信仰赢得了数次战略性的胜利。一些宗派坚决拒绝了如盟约异象（Federal Vision），保罗新观（NPP），以及其他形式的道德主义（即称义是靠恩典加合作）。我凭记忆写下这些宗派的名称，排名不分先后：
北美联合改革宗诸教会（United Reformed Churches in North America，简称URCNA）
正统长老会（Orthodox Presbyterian Church，简称OPC）；
美国长老会（Presbyterian Church in America，简称PCA）；
圣经长老会（Bible Presbyterian Church）；
美国改革宗教会（Reformed Church in the United States ，简称RCUS）；
北美正统改革宗教会（Orthodox Christian Reformed Church，简称OCRC）；
北美改革宗长老会（Reformed Presbyterian Church in North America，简称RPCNA）；
美国改革宗长老会（Reformed Presbyterian Church in the United States，RPCUS）。

不过，这一切并未结束。道德主义正在积蓄力量，准备卷土重来。现在已经出现一股运动，他们起来要回应罗马天主教对宗教改革的批判。他们宣称宗教改革所讲的称义并不是指基督的义（在我们之外的义）归算给我们，而是通过某种形式的「与基督联合」，要么是奥西安德（Osiander）主张的「基督在我们里」，要么就是「我们在基督里」。不论是哪一种，其中心思想都是在说「我们有真实的、内在的义。这个义虽然不是注入的，却是确实的。你总不能说我们不相信圣灵做成在我们里面的内在的义吧。」

这些回应注定失败，因为它们本身都妥协了天主教观点的大前提。这些努力表面上是在肯定唯独因信称义的教义，但其实是在试图维护另一种教导。这种教导就是认为，上帝接纳罪人的原因里有一部分是因为圣灵做成的义，而这是意志的行为。这种观点在神学上是前后不一致的，是不稳固的。在这样的救恩论里并存着两个完全矛盾的观点。然而救恩论不能一事二主，要么上帝接纳罪人的基础是罪人内在的义（不论如何解释），要么上帝接纳罪人的基础是算给他们的外在的义。不能两个都要，只能爱一个，恨另外一个。

当然，我们的确相信圣灵在我们里面做成义。改革宗神学没有否认这样的教导。但是我们不相信，也不承认，更不教导，圣灵做成的义是我们被上帝称义接纳的原因。基督为我们成就了两样好处：称义和成圣。后者紧随前者。成圣是称义的结果和证据。但是成圣本身并不会产生称义，成圣不会促使上帝接纳我们。

我们要回应对因信称义的批判和道德主义，是不能通过妥协称义的教义来达成。如果房子着火了，救火的办法不是跑到地下室再放一把火。我们不能承认称义的基础是圣灵做成的义。我们不是在玩柔道，好像可以先假装倒下然后再翻身得胜。

这种让步根本不会让道德主义满足。道德主义者的野心是要全盘大胜，所以他们从来不会放弃。明确无疑、完全白白的称义，道德主义者恨恶这样的福音，因为他们根本不相信自己是可悲的罪人，他们不相信自己在完全公义，如同烈火一般的上帝面前是绝对无助的。

道德主义一定会卷土重来。他们会重来因为他们从未离开过。可能只是暂时销声匿迹。正因为如此，我们不能掉以轻心说，「我们都知道福音是什么了，现在我们可以把福音放在一边，专注于基督徒生活了。」因为一旦我们说出这样的话来，我们就丢弃了房屋的根基，也失去了基督徒生活的原动力。这就好像在说，「哦，我们都知道呼吸是什么了，所以我们可以把呼吸这件事放在一边，去干点其他更刺激的事。」估计没有人真正这么做。如果你真的想过一个健康的基督徒生活，先从福音的宣告开始。我们如何在生活里对抗自己的罪？我们需要律法。我们如何能打败罪？唯独靠着福音。律法没有力量打败罪。律法的力量在于宣判我们有罪，并且引导我们。律法像铁轨，脱离了铁轨的火车必将奔向毁灭，但是铁轨本身不能给予火车动力前行。只有圣灵上帝能真正给基督徒提供动力，带动他们过基督徒生活。而圣灵工作是藉着福音经常性的忠心的宣告来给罪人提供动力。

基督徒，如果你的立场是这样的，道德主义者会叫你反律法主义者。别被恐吓了。因为他们定义的「反律法主义」是指「否定上帝接纳罪人是根据圣灵做成的义的人」。如果他们这么定义的话，就让他们这么叫好了。当然，这个定义是胡说。真正的反律法主义是否认律法的第三重功用。改革宗基督徒（实际上，所有认信的基督徒）从来没有否认律法的第三重功用，他们都忠心的持守自己的信条。

那么我们应该如何回应律法主义者呢？唯一的回应就是两点：第一，宣讲律法。每一个律法主义者需要听的第一件事是律法。道德主义者之所以成为道德主义者就是因为他们并不真正相信自己是罪人。他们首先需要认清自己到底是谁。他们缺少的是自我认知。他们缺乏对上帝的公义、圣洁、忿怒的真正认识。他们并不真正敬畏上帝，却总把敬虔挂在嘴边。

只有当他们听到振聋发聩的律法时，当他们听到完全、圣洁、公义的律法要求我们完美、永久、个人的义时，我们才能向他们宣告甘甜的福音。保罗在亚略巴古对外邦人如何，我们对道德主义者也应该如何。保罗所宣讲的就是律法（自然律法）加上在人看为愚拙的复活的福音（超自然福音）。结果，有的人信了，但是大部分人不信。我们能得到的结果也不会超过保罗。道德主义没有就此罢休，因为他们永远不会罢休，除非整个世界结束。道德主义一定还会卷土重来。


作者/司考特·克拉克
译/王一 Yi Wang
司考特·克拉克博士（Dr. R. Scott Clark），加州威敏斯特神学院（Westminster Seminary California）历史与系统神学副教授；加州欧申赛德市 Oceanside United Reformed Church 副牧师。

英文原文载于Heidelblog


'''

print(aaa)